@@ -6,7 +6,7 @@ from urllib import parse as url_parse
 
 from authlib.common.security import generate_token
 from authlib.integrations.requests_client import OAuth2Session
-from pydantic import BaseModel, SecretStr
+from pydantic import BaseModel, Field, SecretStr
 
 
 class SecretsKeeper(ABC):
@@ -26,7 +26,7 @@ class SecretsKeeper(ABC):
 class OAuth2ConnectorConfig(BaseModel):
     client_id: str
     client_secret: SecretStr
-    redirect_uri: str
+    redirect_uri: str = Field(user_provided=False)
 
 
 class OAuth2Connector:
@@ -34,14 +34,14 @@ class OAuth2Connector:
 
     def __init__(
         self,
-        name: str,
+        auth_flow_id: str,
         authorization_url: str,
         scope: str,
         config: OAuth2ConnectorConfig,
         secrets_keeper: SecretsKeeper,
         token_url: str,
     ):
-        self.auth_flow_id = name
+        self.auth_flow_id = auth_flow_id
         self.authorization_url = authorization_url
         self.scope = scope
         self.config = config
@@ -64,7 +64,7 @@ class OAuth2Connector:
         self.secrets_keeper.save(self.auth_flow_id, {'state': state})
         return uri
 
-    def retrieve_tokens(self, authorization_response: str):
+    def retrieve_tokens(self, authorization_response: str, **kwargs):
         url = url_parse.urlparse(authorization_response)
         url_params = url_parse.parse_qs(url.query)
         client = OAuth2Session(
@@ -79,7 +79,13 @@ class OAuth2Connector:
             json.loads(saved_flow['state'])['token'] == json.loads(url_params['state'][0])['token']
         )
 
-        token = client.fetch_token(self.token_url, authorization_response=authorization_response)
+        token = client.fetch_token(
+            self.token_url,
+            authorization_response=authorization_response,
+            client_id=self.config.client_id,
+            client_secret=self.config.client_secret.get_secret_value(),
+            **kwargs,
+        )
         self.secrets_keeper.save(self.auth_flow_id, token)
 
     def get_access_token(self) -> str:
